### Advanced

This section is intended for advanced users of this software. Here you can find:

1. [**Advanced Usage**](./advanced.md)
<br>
In this section, you can explore specify source/target languages, switch translation services, and more.

2. [**Language Code**](./Language-Codes.md)
<br>
If you are unsure about which codes to use for translating your source/target languages, you can find them here.

3. [**Documentation of Translation Services**](./Documentation-of-Translation-Services.md)
<br>
If you need to review the documentation provided by the translation services you are using, please refer to this page.